from setuptools import setup

with open('README.md', 'r') as f:
    long_description = f.read()
    
setup(
    name = 'cbrecommender',
    version = '0.0.1',
    author = 'Akash S Panickar',
    author_email = 'akashsabu@ymail.com',
    description = 'Library for implementing Content-Based Recommendation System',
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = 'http://github.com/mochatek/cbrecommender',
    license = 'MIT',
    install_requires = ['pandas','numpy'],
    packages = ['cbrecommender'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    zip_safe = False
    )



    import pandas as pd
import numpy as np

class cbr:
    def __init__(self):
        self.user_profile = None
        
    # OneHotEncode features
    def encode_features(self, features):
        if isinstance(features, pd.DataFrame):
            features = features.squeeze()
        features = features.apply(lambda g:g.lower().replace(' ', ''))
        features = features.str.get_dummies(sep = ',')
        return features

    # Extract user preferences and build User-Profile
    def fit(self, features, score):
        feature_matrix = features.values
        score_matrix = np.array(score, ndmin = 2, dtype = float)
        profile_matrix = score_matrix.dot(feature_matrix)
        sum = profile_matrix.sum()
        profile_matrix = profile_matrix / sum
        self.user_profile =  pd.DataFrame(profile_matrix, columns = features.columns)
        return self.user_profile

    # Recommend items based on User-Profile
    def recommend(self, items, features, score = 0, num = None):
        if isinstance(items, pd.DataFrame):
            items = items.squeeze()
        feature_matrix = features.values
        expected_scores = (feature_matrix * self.user_profile.values).sum(axis = 1) * 10
        df = pd.DataFrame({
            'item' : items,
            'expected score' : expected_scores}).sort_values('expected score', ascending = False)
        return df[df['expected score'] >= score].iloc[:num, :]
